@@ -224,8 +224,9 @@ class ApplePanelA : public ApplePanel
     enum { kApplePanelLevels = 128 };
 
 private:
-    IONDRVFramebuffer*			fFramebuffer;
-    UInt8						fValues[ kApplePanelLevels + 1 ];
+    IONDRVFramebuffer*	fFramebuffer;
+    UInt8		fValues[ kApplePanelLevels + 1 ];
+    bool 		fNoNVRAM ;
 
 public:
     virtual bool start(	IOService * provider );
@@ -2417,8 +2418,10 @@ struct VDBacklightControlInfo {
 bool ApplePanelA::start( IOService * provider )
 {
     IORegistryEntry * parent;
+    IORegistryEntry * regEntry;
     bool pmu = false;
-
+    OSData*	    data;
+    
     parent = provider->copyParentEntry( gIODTPlane );
     if( parent) {
         pmu = (0 == strcmp("via-pmu", parent->getName()));
@@ -2429,7 +2432,20 @@ bool ApplePanelA::start( IOService * provider )
 
     if( !super::start( provider))
         return( false );
-
+    
+   // Assume that there is no NVRAM
+    fNoNVRAM  = true;
+    if ((regEntry = IORegistryEntry::fromPath("/options", gIODTPlane)))
+    {
+        if ( 0 != ( data = OSDynamicCast( OSData, regEntry->getProperty( "aapl,pci" ) ) ) )
+        {
+            // If there is value in the aapl,pci property, NVRAM has been initialized
+            if (data->getLength() > 0)
+                 fNoNVRAM  = false;
+        }
+	regEntry->release();
+    }
+ 
     return( true );
 }
 
@@ -2467,7 +2483,7 @@ bool ApplePanelA::setDisplay( IODisplay * display )
         err = fFramebuffer->doStatus( kPanelABacklightControl, &info);
         if( (kIOReturnSuccess == err)
          && (kBacklightPowerOff == info.backlightOnOff)
-         && (0 == info.backlightLevel)) {
+         && (0 == info.backlightLevel) || fNoNVRAM ) {
             info.saveNVRAM = 0;
             info.backlightLevel = fPanelInfo->max;
             info.backlightOnOff = kBacklightPowerOn;
